/****************************************************************************
** ManDVD
**
** Created: Mon May 08 14:00:00 2006
**      by: Gibault Stphane
**	Hacked on by Mikael Bhm micko@bag.org
**
** This is a tool for simply creating DVD Video
** 
****************************************************************************/
//
// C++ Interface: animation
//
// Description: Headerfile for animation generation
//
//
// Author: Mikael Bhm <micko@bag.org>, (C) 2008
//
// Copyright: See COPYING file that comes with this distribution
//
//


#ifndef ANIMATION_H
#define ANIMATION_H

#include "mandvd_global.h"
#include <mainfrm.h>
#include <qlabel.h>
#include <qtoolbutton.h>
#include <qbuttongroup.h>
#include <qlineedit.h>
#include <qcombobox.h>
#include <qslider.h>
#include <qtextedit.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qradiobutton.h>
#include <qmessagebox.h>
#include <qregexp.h>
#include <qprogressbar.h>
#include <qlistview.h>
#include <qdatetimeedit.h>
#include <dialog.h>

/* Declarations for animations by Mikael */



#endif